# Init file

# Constants
__version__: str = '0.1.0.2'
__author__: str = 'Samuel de Oliveira'
__license__: str = 'MIT'
__all__: list = []
__doc__: str = """
-*--------- The PyRubik official docs ---------*-

    Everything can be found at this link:
    https://github.com/Samuel-de-Oliveira/PyRubik

-*----------------------------------------------*-
"""

if __name__ == '__main__':
    print(
        'This is a module file, then you should import it.\n'
        + 'Plase, take a look in https://github.com/Samuel-de-Oliveira/PyRubik for more info'
    )
